@@ -6,7 +6,7 @@ class Cli:
     def run(config=None):
         from mdblog.config import CONFIG
 
-        # print(config)
+        print(config)
         if config:
             CONFIG.update(**toml.load(config))
         print(CONFIG)
@@ -15,7 +15,7 @@ class Cli:
         # print(CONFIG)
         mdblog.start_server()
 def main():
-    # fire.Fire(Cli)
-    Cli.run()
+    fire.Fire(Cli)
+    # Cli.run()
 if __name__ == '__main__':
     main()
